==> objectify-alpha_29.8.tgz: objectify-alpha_29.8/testing/test_remove_file.sh <==
# 
#              This file is part of the New World OS project
#                     Copyright (C) 2009 QRW Software
#            J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
#                       http://www.qrwsoftware.com
#                       http://nwos.sourceforge.com
# 
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
# 
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
# 
#    You should have received a copy of the GNU General Public License
#    along with this program, in the file LICENSE.  If not, see 
#    <http://www.gnu.org/licenses/>.
# 
#    You can also contact me via paper mail at:
# 
#       QRW Software
#       P.O. Box 27511
#       Salt Lake City, UT 84127-0511, USA.
# 
# 
#  This script runs a quick test of file importing and exporting.
# 
#  $Log: test_remove_file.sh,v $
#  Revision 1.2  2009/01/21 15:57:00  jsedwards
#  Added test to verify that entire test directory was removed.
#
#  Revision 1.1  2009/01/21 15:38:14  jsedwards
#  Initial script to test remove_file (really tests removing objects from a
#  reference_list).
#

export OBJECTIFY_TEST_ONLY_DO_NOT_USE="Remove Files Test"
export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private.obj
export OBJECTIFY_LOG_FILE_PATH=/tmp/objectify_test/objectify_log
export OBJECTIFY_BACKUP_PATH=/tmp/objectify_test

EXEC=$PWD

if ! rm -fr /tmp/objectify_test; then
   echo ""
   echo "could not remove /tmp/objectify_test directory"
   echo ""
   exit 1
fi

if ! rm -fr /tmp/test; then
   echo ""
   echo "could not remove /tmp/test directory"
   echo ""
   exit 1
fi

mkdir /tmp/test
cd /tmp/test


echo "------------------"
echo " prep..."
echo "------------------"

echo $OBJECTIFY_PRIVATE_PATH

if ! $EXEC/prep_disk 32M; then
   echo ""
   echo "prep_disk failed"
   echo ""
   exit 1
fi

sleep 1

echo "---------------------"
echo " creating files..."
echo "---------------------"

mkdir dir-1

for ((num=1; num<250; num++)) do
    echo "File: $num" >> dir-1/file-$num.txt
done

if ! $EXEC/import_file --very-low-security -r dir-1/; then
   echo ""
   echo "import_file failed"
   echo ""
   exit 1
fi

if ! $EXEC/verify_file --remove-no-shred -r dir-1/; then
   echo ""
   echo "verify_file failed"
   echo ""
   exit 1
fi


for ((num=0; num<200; num++)); do
    echo "**********************************"
    file=`list_files | $EXEC/attic/random_line`
    echo $file;

    if ! $EXEC/compress_sparse compressed-$num; then
       echo ""
       echo "compress_sparse failed"
       echo ""
       exit 1
    fi

    if ! $EXEC/remove_file --all-traces $file; then
       echo ""
       echo "remove_file failed"
       echo ""
       exit 1
    fi

    if export_file "*"; then
       if ! $EXEC/verify_file --remove-no-shred -r dir-1/; then
          echo ""
          echo "verify_file failed"
          echo ""
          exit 1
       fi

       if [ -d dir-1 ]; then
          echo ""
          echo "verify_file --remove failed to remove dir-1"
          echo ""
          exit 1
       fi
    else
       echo ""
       echo "export_file failed"
       echo ""
       exit 1
    fi
done

==> objectify-alpha_30.2.tgz: objectify-alpha_30.2/testing/test_remove_file.sh <==
# 
#              This file is part of the New World OS project
#                     Copyright (C) 2009 QRW Software
#            J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
#                       http://www.qrwsoftware.com
#                       http://nwos.sourceforge.com
# 
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
# 
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
# 
#    You should have received a copy of the GNU General Public License
#    along with this program, in the file LICENSE.  If not, see 
#    <http://www.gnu.org/licenses/>.
# 
#    You can also contact me via paper mail at:
# 
#       QRW Software
#       P.O. Box 27511
#       Salt Lake City, UT 84127-0511, USA.
# 
# 
#  This script runs a quick test of file importing and exporting.
# 
#  $Log: test_remove_file.sh,v $
#  Revision 1.3  2009/03/08 14:09:22  jsedwards
#  Updated for new prep_disk.
#
#  Revision 1.2  2009/01/21 15:57:00  jsedwards
#  Added test to verify that entire test directory was removed.
#
#  Revision 1.1  2009/01/21 15:38:14  jsedwards
#  Initial script to test remove_file (really tests removing objects from a
#  reference_list).
#

export OBJECTIFY_TEST_ONLY_DO_NOT_USE="Remove Files Test"
export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private.obj
export OBJECTIFY_LOG_FILE_PATH=/tmp/objectify_test/objectify_log
export OBJECTIFY_BACKUP_PATH=/tmp/objectify_test

EXEC=$PWD

if ! rm -fr /tmp/objectify_test; then
   echo ""
   echo "could not remove /tmp/objectify_test directory"
   echo ""
   exit 1
fi

if ! rm -fr /tmp/test; then
   echo ""
   echo "could not remove /tmp/test directory"
   echo ""
   exit 1
fi

mkdir /tmp/test
cd /tmp/test


echo "------------------"
echo " prep..."
echo "------------------"

echo $OBJECTIFY_PRIVATE_PATH

if ! $EXEC/prep_disk; then
   echo ""
   echo "prep_disk failed"
   echo ""
   exit 1
fi

sleep 1

echo "---------------------"
echo " creating files..."
echo "---------------------"

mkdir dir-1

for ((num=1; num<250; num++)) do
    echo "File: $num" >> dir-1/file-$num.txt
done

if ! $EXEC/import_file --very-low-security -r dir-1/; then
   echo ""
   echo "import_file failed"
   echo ""
   exit 1
fi

if ! $EXEC/verify_file --remove-no-shred -r dir-1/; then
   echo ""
   echo "verify_file failed"
   echo ""
   exit 1
fi


for ((num=0; num<200; num++)); do
    echo "**********************************"
    file=`list_files | $EXEC/attic/random_line`
    echo $file;

    if ! $EXEC/compress_sparse compressed-$num; then
       echo ""
       echo "compress_sparse failed"
       echo ""
       exit 1
    fi

    if ! $EXEC/remove_file --all-traces $file; then
       echo ""
       echo "remove_file failed"
       echo ""
       exit 1
    fi

    if export_file "*"; then
       if ! $EXEC/verify_file --remove-no-shred -r dir-1/; then
          echo ""
          echo "verify_file failed"
          echo ""
          exit 1
       fi

       if [ -d dir-1 ]; then
          echo ""
          echo "verify_file --remove failed to remove dir-1"
          echo ""
          exit 1
       fi
    else
       echo ""
       echo "export_file failed"
       echo ""
       exit 1
    fi
done
